# yarpc-python

[![Build Status](https://travis-ci.org/yarpc/yarpc-python.svg?branch=master)](https://travis-ci.org/yarpc/yarpc-python) [![PyPI version](https://badge.fury.io/py/yarpc.svg)](https://badge.fury.io/py/yarpc)

**This project is currently WIP and not ready for use. Do not use it until this notice goes away.**
